@@ -1,5 +1,6 @@
 test_that("broom methods work", {
-  withr::local_package("broom")
+  skip_if_not_installed("withr")
+  skip_if_not_installed("broom")
 
   model <- parsnip::linear_reg() %>%
     parsnip::set_engine("lm") %>%
@@ -9,6 +10,7 @@ test_that("broom methods work", {
     model, z ~ x + y + a + b,
     tidyr::nest(example_nested_data, data = -"id")
   )
+  
   withr::with_package("broom", {
     tidy(fit)
     expect_equal(nrow(glance(fit)), 1)
